@@ -97,7 +97,7 @@ namespace Oxygen
         }
 
         //! enability
-        virtual void setEnabled( bool value )
+        void setEnabled( bool value )
         {
             BaseEngine::setEnabled( value );
             /*
@@ -111,7 +111,7 @@ namespace Oxygen
         }
 
         //! duration
-        virtual void setDuration( int value )
+        void setDuration( int value )
         {
             BaseEngine::setDuration( value );
             _data.setDuration( value );
@@ -120,7 +120,7 @@ namespace Oxygen
         public Q_SLOTS:
 
         //! remove widget from map
-        virtual bool unregisterWidget( QObject* object )
+        bool unregisterWidget( QObject* object )
         { return _data.unregisterWidget( object ); }
 
         private:
