@@ -72,7 +72,7 @@ namespace Oxygen
         { return _registeredWidgets.contains( widget ); }
 
         //* event filter
-        virtual bool eventFilter( QObject*, QEvent*);
+        bool eventFilter( QObject*, QEvent*) ;
 
         //* set contrast
         void setHasContrast( const QWidget* widget, bool ) const;
@@ -223,19 +223,19 @@ namespace Oxygen
 
         //* update geometry
         /** nothing is done. Rect must be passed explicitly */
-        virtual void updateGeometry( void )
+        void updateGeometry( void )
         {}
 
         //* update geometry
-        virtual void updateGeometry( QRect );
+        void updateGeometry( QRect ) ;
 
         //* update state
-        void updateState( bool focus, bool hover, qreal opacity, AnimationMode );
+        void updateState( bool focus, bool hover, qreal opacity, AnimationMode ) ;
 
         protected:
 
         //* painting
-        virtual void paintEvent(QPaintEvent *);
+        void paintEvent(QPaintEvent *) ;
 
         private:
 
@@ -272,15 +272,15 @@ namespace Oxygen
         {}
 
         //* update geometry
-        virtual void updateGeometry( void );
+        void updateGeometry( void ) ;
 
         //* update geometry
-        virtual void updateGeometry( QRect );
+        void updateGeometry( QRect ) ;
 
         protected:
 
         //* painting
-        virtual void paintEvent(QPaintEvent *);
+        void paintEvent(QPaintEvent *) ;
 
         private:
 
